@@ -25,86 +25,37 @@ _logger = logging.getLogger(__name__)
 class Connection(object):
 
     _ENV_S3_STAGING_DIR = "AWS_ATHENA_S3_STAGING_DIR"
+    _ENV_S3_OUTPUT_LOCATION = "AWS_ATHENA_S3_OUTPUT_LOCATION"
     _ENV_WORK_GROUP = "AWS_ATHENA_WORK_GROUP"
     _BASE_PATH = os.path.dirname(os.path.abspath(__file__))
 
     def __init__(
         self,
-        s3_staging_dir=None,
-        access_key=None,
-        secret_key=None,
-        region_name=None,
-        schema_name="default",
-        profile_name=None,
-        credential_file=None,
         jvm_path=None,
         jvm_options=None,
         converter=None,
         formatter=None,
         driver_path=None,
         log4j_conf=None,
-        work_group=None,
         **driver_kwargs
     ):
-        self.s3_staging_dir = (
-            s3_staging_dir
-            if s3_staging_dir
-            else os.getenv(self._ENV_S3_STAGING_DIR, None)
-        )
-        self.work_group = (
-            work_group if work_group else os.getenv(self._ENV_WORK_GROUP, None)
-        )
-        self.schema_name = schema_name
-
-        assert schema_name, "Required argument `schema_name` not found."
-        assert (
-            self.s3_staging_dir or self.work_group
-        ), "Required argument `s3_staging_dir` or `work_group` not found."
-
-        if credential_file:
-            self.access_key = None
-            self.secret_key = None
-            self.token = None
-            self.profile_name = None
-            self.credential_file = credential_file
-            assert (
-                self.credential_file
-            ), "Required argument `credential_file` not found."
-            self.region_name = region_name
-            assert self.region_name, "Required argument `region_name` not found."
-        else:
-            import botocore.session
-
-            session = botocore.session.get_session()
-            if access_key and secret_key:
-                session.set_credentials(access_key, secret_key)
-            if profile_name:
-                session.set_config_variable("profile", profile_name)
-            if region_name:
-                session.set_config_variable("region", region_name)
-            credentials = session.get_credentials()
-            self.access_key = credentials.access_key
-            assert self.access_key, "Required argument `access_key` not found."
-            self.secret_key = credentials.secret_key
-            assert self.secret_key, "Required argument `secret_key` not found."
-            self.token = credentials.token
-            self.profile_name = session.profile
-            self.credential_file = None
-            self.region_name = session.get_config_variable("region")
-            assert self.region_name, "Required argument `region_name` not found."
-
         self._start_jvm(jvm_path, jvm_options, driver_path, log4j_conf)
-
         self._driver_kwargs = driver_kwargs
+        self.region_name = self._driver_kwargs.get(
+            "AwsRegion", os.getenv("AWS_DEFAULT_REGION", None)
+        )
+        self.schema_name = self._driver_kwargs.get("Schema", "default")
+        self.work_group = self._driver_kwargs.get(
+            "Workgroup", os.getenv(self._ENV_WORK_GROUP, None)
+        )
         props = self._build_driver_args()
         jpype.JClass(ATHENA_DRIVER_CLASS_NAME)
-        self._jdbc_conn = jpype.java.sql.DriverManager.getConnection(
-            ATHENA_CONNECTION_STRING.format(
-                region=self.region_name, schema=schema_name
-            ),
-            props,
-        )
-
+        if self.region_name:
+            self._jdbc_conn = jpype.java.sql.DriverManager.getConnection(
+                ATHENA_CONNECTION_STRING.format(region=self.region_name), props
+            )
+        else:
+            self._jdbc_conn = jpype.java.sql.DriverManager.getConnection()
         self._converter = converter if converter else JDBCTypeConverter()
         self._formatter = formatter if formatter else ParameterFormatter()
 
@@ -150,31 +101,20 @@ class Connection(object):
 
     def _build_driver_args(self):
         props = jpype.java.util.Properties()
-        if self.credential_file:
-            props.setProperty(
-                "AwsCredentialsProviderClass",
-                "com.simba.athena.amazonaws.auth.PropertiesFileCredentialsProvider",
-            )
-            props.setProperty(
-                "aws_credentials_provider_arguments", self.credential_file
-            )
-        elif self.profile_name:
-            props.setProperty(
-                "AwsCredentialsProviderClass",
-                "com.simba.athena.amazonaws.auth.profile.ProfileCredentialsProvider",
-            )
-            props.setProperty("aws_credentials_provider_arguments", self.profile_name)
-        elif self.token:
-            props.setProperty(
-                "AwsCredentialsProviderClass",
-                "com.simba.athena.amazonaws.auth.DefaultAWSCredentialsProviderChain",
-            )
-        else:
-            props.setProperty("UID", self.access_key)
-            props.setProperty("PWD", self.secret_key)
-        props.setProperty("Schema", self.schema_name)
-        if self.s3_staging_dir:
-            props.setProperty("S3OutputLocation", self.s3_staging_dir)
+        props.setProperty(
+            "AwsCredentialsProviderClass",
+            "com.simba.athena.amazonaws.auth.DefaultAWSCredentialsProviderChain",
+        )
+        s3_staging_dir = os.getenv(self._ENV_S3_STAGING_DIR, None)
+        if s3_staging_dir:
+            props.setProperty("S3OutputLocation", s3_staging_dir)
+        s3_output_location = os.getenv(self._ENV_S3_OUTPUT_LOCATION, None)
+        if s3_output_location:
+            props.setProperty("S3OutputLocation", s3_output_location)
+        if self.region_name:
+            props.setProperty("AwsRegion", self.region_name)
+        if self.schema_name:
+            props.setProperty("Schema", self.schema_name)
         if self.work_group:
             props.setProperty("Workgroup", self.work_group)
         for k, v in iteritems(self._driver_kwargs):
